@@ -1,3 +1,3 @@
 from GenderPrediction.gender_prediction import GenderPredictor
 
-print(GenderPredictor.predict('Sounak'))
\ No newline at end of file
+print(GenderPredictor(name='Sounak').predict())
\ No newline at end of file
